# Table of Contents

- [review-criteria-custom-reports](<./review-criteria-custom-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Review Criteria for Custom Reports](<./Review-Criteria-for-Custom-Reports.md>)
  - [Report Metadata Review](<./Review-Criteria-for-Custom-Reports/Report-Metadata-Review.md>)
  - [Technical Review](<./Review-Criteria-for-Custom-Reports/Technical-Review.md>)
  - [Functional Review](<./Review-Criteria-for-Custom-Reports/Functional-Review.md>)
